pub enum Chunk<'a> {
Start(File),
IntermediateOrEnd(Record<'a>),
}Expand description
A chunk of real-time data within a volume. Chunks are ordered and when concatenated together form a complete volume of radar data. All chunks contain an LDM record with radar data messages.
Variants
Start(File)
The start of a new volume. This chunk will begin with an Archive II volume header followed by a compressed LDM record.
IntermediateOrEnd(Record<'a>)
An intermediate or end chunk. This chunk will contain a compressed LDM record with radar data messages.
Implementations
Sourceimpl Chunk<'_>
impl Chunk<'_>
Sourcepub fn new(data: Vec<u8>) -> Result<Self>
pub fn new(data: Vec<u8>) -> Result<Self>
Creates a new chunk from the provided data. The data is expected to be in one of two formats:
- An Archive II volume header followed by a compressed LDM record, or a “start” chunk.
- A compressed LDM record, or an “intermediate” or “end” chunk.
The chunk type is determined by the data’s format.