pub enum NextChunk {
Sequence(ChunkIdentifier),
Volume(VolumeIndex),
}Expand description
Identifies where to find the next expected chunk.
Variants
Sequence(ChunkIdentifier)
The next chunk is expected to be located in the same volume at this sequence. The ChunkIdentifier::with_sequence method can be used to create the next chunk’s identifier and it can be downloaded using the crate::aws::realtime::download_chunk() function. You may need to poll by checking if that function returns crate::result::aws::AWSError::S3ObjectNotFoundError.
Volume(VolumeIndex)
The chunk is expected to be located in the next volume. The next volume’s chunks can be listed using the crate::aws::realtime::list_chunks_in_volume() function.