pub enum PollStats {
LatestVolumeCalls(usize),
NewVolumeCalls(usize),
NewChunk(NewChunkStats),
}Expand description
Statistics from the polling process.
Variants
LatestVolumeCalls(usize)
The number of network calls made to find the most recent volume.
NewVolumeCalls(usize)
The number of network calls made to find a new volume.
NewChunk(NewChunkStats)
Statistics for a new chunk.