ChunkIdentifier

Struct ChunkIdentifier 

pub struct ChunkIdentifier { /* private fields */ }
Identifies a volume chunk within the real-time NEXRAD data bucket. These chunks are uploaded every few seconds and contain a portion of the radar data for a specific volume.

Implementations

Source

impl ChunkIdentifier

pub fn new( site: String, volume: VolumeIndex, name: String, date_time: Option<DateTime<Utc>>, ) -> Self

Creates a new chunk identifier.

pub fn with_sequence(&self, sequence: usize) -> Self

Creates a new chunk identifier with the given sequence number. The chunk type will be inferred from the sequence and date/time will be omitted since it is unknown.

pub fn site(&self) -> &str

The chunk’s radar site identifier.

pub fn volume(&self) -> &VolumeIndex

The chunk’s rotating volume index.

pub fn name(&self) -> &str

The chunk’s name.

pub fn name_prefix(&self) -> &str

The chunk’s name prefix.

pub fn sequence(&self) -> Option<usize>

The sequence number of this chunk within the volume.

pub fn chunk_type(&self) -> Option<ChunkType>

The position of this chunk within the volume.

pub fn date_time(&self) -> Option<DateTime<Utc>>

The date and time this chunk was uploaded.

pub fn next_chunk(&self) -> Option<NextChunk>

Identifies the next chunk’s expected location.