pub struct LatestVolumeResult {
pub volume: Option<VolumeIndex>,
pub calls: usize,
}Expand description
Represents the most recent volume index and the number of network calls made to find it.
Fields
volume: Option<VolumeIndex>The most recent volume index, if found.
calls: usizeThe number of network calls made to find the most recent volume.