NewChunkStats

Struct NewChunkStats 

pub struct NewChunkStats {
    pub calls: usize,
    pub latency: Option<Duration>,
}
Statistics for a new chunk.

Fields

calls: usize

The number of network calls made to find a new chunk.

latency: Option<Duration>

The latency between when a chunk was uploaded to S3 and when it was downloaded.