pub struct ChunkIdentifier { /* private fields */ }Expand description
Identifies a volume chunk within the real-time NEXRAD data bucket. These chunks are uploaded every few seconds and contain a portion of the radar data for a specific volume.
Implementations
Sourceimpl ChunkIdentifier
impl ChunkIdentifier
Sourcepub fn new(
site: String,
volume: VolumeIndex,
name: String,
date_time: Option<DateTime<Utc>>,
) -> Self
pub fn new( site: String, volume: VolumeIndex, name: String, date_time: Option<DateTime<Utc>>, ) -> Self
Creates a new chunk identifier.
Sourcepub fn with_sequence(&self, sequence: usize) -> Self
pub fn with_sequence(&self, sequence: usize) -> Self
Creates a new chunk identifier with the given sequence number. The chunk type will be inferred from the sequence and date/time will be omitted since it is unknown.
Sourcepub fn volume(&self) -> &VolumeIndex
pub fn volume(&self) -> &VolumeIndex
The chunk’s rotating volume index.
Sourcepub fn name_prefix(&self) -> &str
pub fn name_prefix(&self) -> &str
The chunk’s name prefix.
Sourcepub fn chunk_type(&self) -> Option<ChunkType>
pub fn chunk_type(&self) -> Option<ChunkType>
The position of this chunk within the volume.
Sourcepub fn next_chunk(&self) -> Option<NextChunk>
pub fn next_chunk(&self) -> Option<NextChunk>
Identifies the next chunk’s expected location.