pub struct NewChunkStats {
pub calls: usize,
pub latency: Option<Duration>,
}Expand description
Statistics for a new chunk.
Fields
calls: usizeThe number of network calls made to find a new chunk.
latency: Option<Duration>The latency between when a chunk was uploaded to S3 and when it was downloaded.